@@ -5,9 +5,9 @@
 #' upweights if first name is uncommon.
 #'
 #' @usage nameReweight(dfA, dfB, EM, gammalist, matchesLink,
-#' varnames, stringdist.match, partial.match,
+#' varnames, stringdist.match, numeric.match, partial.match,
 #' firstname.field, threshold.match, stringdist.method, cut.a, cut.p,
-#' jw.weight, n.cores)
+#' jw.weight, cut.a.num, cut.p.num, n.cores)
 #' @param dfA The full version of dataset A that is being matched.
 #' @param dfB The full version of dataset B that is being matched.
 #' @param EM The EM object from \code{emlinkMARmov()}
@@ -20,6 +20,9 @@
 #' @param stringdist.match A vector of booleans, indicating whether to use
 #' string distance matching when determining matching patterns on
 #' each variable. Must be same length as varnames.
+#' @param numeric.match A vector of booleans, indicating whether to use
+#' numeric pairwise distance matching when determining matching patterns on
+#' each variable. Must be same length as varnames.
 #' @param partial.match A vector of booleans, indicating whether to include
 #' a partial matching category for the string distances. Must be same length
 #' as varnames. Default is FALSE for all variables.
@@ -32,6 +35,8 @@
 #' @param cut.a Lower bound for full string-distance match, ranging between 0 and 1. Default is 0.92
 #' @param cut.p Lower bound for partial string-distance match, ranging between 0 and 1. Default is 0.88
 #' @param jw.weight Parameter that describes the importance of the first characters of a string (only needed if stringdist.method = "jw"). Default is .10
+#' @param cut.a.num Lower bound for full numeric match. Default is 1
+#' @param cut.p.num Lower bound for partial numeric match. Default is 2.5
 #' @param n.cores Number of cores to parallelize over. Default is NULL.
 #'
 #' @return \code{nameReweight()} returns a list containing the following elements:
@@ -40,10 +45,11 @@
 #' @author Ted Enamorado <ted.enamorado@gmail.com> and Ben Fifield <benfifield@gmail.com>
 #' @export
 nameReweight <- function(dfA, dfB, EM, gammalist, matchesLink,
-                         varnames, stringdist.match, partial.match, 
+                         varnames, stringdist.match,
+                         numeric.match, partial.match, 
                          firstname.field, threshold.match,
                          stringdist.method = "jw", cut.a = .92, cut.p = .88,
-                         jw.weight = .10, n.cores = NULL){
+                         jw.weight = .10, cut.a.num = 1, cut.p.num = 2.5, n.cores = NULL){
 
     if(!(stringdist.method %in% c("jw", "jaro", "lv"))){
         stop("Invalid string distance method. Method should be one of 'jw', 'jaro', or 'lv'.")
@@ -56,6 +62,9 @@ nameReweight <- function(dfA, dfB, EM, gammalist, matchesLink,
     if(sum(firstname.field) == 0){
         stop("You have not indicated which field represents first name.")
     }
+    if(any(stringdist.match * numeric.match) == 1){
+        stop("There is a variable present in both 'numeric.match' and 'stringdist.match'. Please select only one matching metric for each variable.")
+    }
     
     ## Get cores
     if(is.null(n.cores)) {
@@ -97,9 +106,9 @@ nameReweight <- function(dfA, dfB, EM, gammalist, matchesLink,
     namevec <- rep(NA, length(varnames))
     for(i in 1:length(gammalist)){
         ## Convert to character
-        if(is.factor(matchesA.f[,varnames[i]]) | is.factor(matchesB.f[,varnames[i]])){
-            matchesA.f[,varnames[i]] <- as.character(matchesA.f[,varnames[i]])
-            matchesB.f[,varnames[i]] <- as.character(matchesB.f[,varnames[i]])
+        if(is.factor(matchesA[,varnames[i]]) | is.factor(matchesB[,varnames[i]])){
+            matchesA[,varnames[i]] <- as.character(matchesA[,varnames[i]])
+            matchesB[,varnames[i]] <- as.character(matchesB[,varnames[i]])
         }
         ## Get matches
         if(stringdist.match[i]){
@@ -109,11 +118,11 @@ nameReweight <- function(dfA, dfB, EM, gammalist, matchesLink,
                 }else{
                     p1 <- NULL
                 }
-                tmp <- 1 - stringdist(matchesA.f[,varnames[i]], matchesB.f[,varnames[i]], "jw", p = p1)
+                tmp <- 1 - stringdist(matchesA[,varnames[i]], matchesB[,varnames[i]], "jw", p = p1)
             }else{
-                t <- stringdist(matchesA.f[,varnames[i]], matchesB.f[,varnames[i]], method = stringdist.method)
-                t.1 <- nchar(matchesA.f[,varnames[i]])
-                t.2 <- nchar(matchesB.f[,varnames[i]])
+                t <- stringdist(matchesA[,varnames[i]], matchesB[,varnames[i]], method = stringdist.method)
+                t.1 <- nchar(matchesA[,varnames[i]])
+                t.2 <- nchar(matchesB[,varnames[i]])
                 o <- ifelse(t.1 > t.2, t.1, t.2)
                 tmp <- 1 - t * (1/o)
             }
@@ -124,13 +133,19 @@ nameReweight <- function(dfA, dfB, EM, gammalist, matchesLink,
             }else{
                 gammalist[[i]] <- ifelse(tmp >= cut.a, 2, 0)
             }
+        }else if(numeric.match[i]){
+            tmp <- calcPWDcpp(matchesA[,varnames[i]], matchesB[,varnames[i]])
+            if(partial.match[i]){
+                gammalist[[i]] <- ifelse(
+                    tmp >= cut.a.num, 2, ifelse(tmp >= cut.p.num, 1, 0)
+                )
+            }else{
+                gammalist[[i]] <- ifelse(tmp >= cut.a.num, 2, 0)
+            }
         }else{
-            tmp <- matchesA.f[,varnames[i]] == matchesB.f[,varnames[i]]
+            tmp <- matchesA[,varnames[i]] == matchesB[,varnames[i]]
             gammalist[[i]] <- ifelse(tmp == TRUE, 2, 0)
         }
-
-        namevec[i] <- paste0("gamma.", i)
-        
     }
     gammalist <- data.frame(do.call(cbind, gammalist))
     names(gammalist) <- namevec
